/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse;

import org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer;
import org.eclipse.core.runtime.preferences.DefaultScope;
import org.eclipse.core.runtime.preferences.IEclipsePreferences;
import org.vcs.bazaar.client.BazaarClientFactory;
import org.vcs.bazaar.client.BazaarClientPreferences;
import org.vcs.bazaar.client.BazaarPreference;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.CommandLineClientFactory;

/**
 *
 * @author Guillermo Gonzalez
 * @author Piotr Piastucki
 *
 */
public class PreferenceInitializer extends AbstractPreferenceInitializer {

	public PreferenceInitializer() {
		super();
	}
	
	private String whoami() {
		try {
			ClientProperties properties = EclipseBazaarCore.getDefault().getClientProperties(null, null, null);
			BazaarClientPreferences.getInstance().set(BazaarPreference.BZR_PLUGIN_PATH, properties.getPluginPath());
			IBazaarClient client = BazaarClientFactory.createClient(CommandLineClientFactory.CLIENT_TYPE);
			return client.whoami();
		} catch (Exception e) {
		}
		return "";
	}

	@Override
	public void initializeDefaultPreferences() {
		IEclipsePreferences p = new DefaultScope().getNode(EclipseBazaarCore.getPluginId());
		p.putBoolean(IBazaarCoreConstants.OVERWRITE_EMAIL, true);
		p.putInt(IBazaarCoreConstants.LOG_REVISION_LIMIT, 200);
		p.put(BazaarPreference.EXECUTABLE.name(), BazaarClientPreferences.getInstance().getString(BazaarPreference.EXECUTABLE));
		String name = whoami();
		p.put(BazaarPreference.BZR_EMAIL.name(), name.isEmpty() ? System.getProperty("user.name") : name);
		p.putInt(BazaarPreference.BZR_XMLRPC_PORT.name(), 11111);
	}

}
