/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.syntax.IReconfigureOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class ReconfigureCommand extends BazaarCommand {

	private final IBzrBranch branch;

	public ReconfigureCommand(IBzrBranch branch) {
		this.branch = branch;
	}

	@Override
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.Reconfiguring_taskName, branch.getBranchLocation().toString()), 100); //$NON-NLS-1$
			IBazaarClient client = getClient(branch, false);
			client.reconfigure(branch.getBranchLocation(), new CommandProgressListener(monitor), IReconfigureOptions.CHECKOUT);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		}
	}

}
