/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class UpdateCommand extends ResourceChangeCommand {

	private IBzrBranch branch;

	public UpdateCommand(IBzrBranch branch) {
		super();
		this.branch = branch;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask("Update command", 100);
			monitor.setTaskName("Updating");
			IBazaarClient client = getClient(branch);
			client.update(branch.getFile(), new CommandProgressListener(monitor));
		} catch (BazaarClientException e) {
			if (!setPostCommandErrorOnConflicts(e.getMessage())) {
				throw BazaarException.wrapException(e);
			}
		} finally {
			monitor.done();
		}
		return BzrWorkspaceRoot.findProjectsInBranch(branch);
	}

}
