/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.compare;

import java.io.InputStream;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;

public class BazaarRevisionNode extends BazaarResourceNode {

	private final IStorageBazaarRevision rev;

	public BazaarRevisionNode(IBzrLocalResource resource) {
		super(resource);
		this.rev = new IStorageBazaarRevision(resource.getIResource());
	}

	public BazaarRevisionNode(IBzrLocalResource resource, BazaarRevision revision) {
		super(resource);
		this.rev = new IStorageBazaarRevision(resource.getIResource(), revision);
	}

	public BazaarRevisionNode(IResource resource, IStorageBazaarRevision rev) {
		super(resource);
		this.rev = rev;
	}

	@Override
	public InputStream getContents() throws CoreException {
		return rev.getContents();
	}

	@Override
	protected InputStream createStream() throws CoreException {
		return getContents();
	}

	@Override
	public boolean isEditable() {
		return false;
	}

	@Override
	public String getCharset() {
		String charset = null;
		try {
			charset = rev.getCharset();
		} catch (CoreException e) {
		} finally {
			if(charset == null) {
				charset = super.getCharset();
			}
		}
		return charset;
	}
	
	public BazaarRevision getRevision() {
		return rev.getRevision();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (super.equals(obj)) {
			if (obj instanceof BazaarRevisionNode) {
				return rev.getRevision().equals(((BazaarRevisionNode) obj).rev.getRevision());
			}
		}
		return false;
	}
}